/*
 * Copyright (C) 2014 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.android.build.gradle.internal.tasks.multidex;

import com.google.common.collect.Lists;

import junit.framework.TestCase;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.List;
import java.util.Map;

/**
 */
public class RetraceMainDexListTest extends TestCase {

    public void testCreateDict() throws IOException {
        InputStream stream = getClass().getResourceAsStream("mapping.txt");
        assertNotNull(stream);

        BufferedReader reader = new BufferedReader(new InputStreamReader(stream));
        try {
            List<String> lines = Lists.newArrayList();

            String line;
            while ((line = reader.readLine()) != null) {
                lines.add(line);
            }

            Map<String, String> map = RetraceMainDexList.createDict(lines);

            assertEquals("android/support/multidex/MultiDex.class", map.get("android/support/a/a.class"));
            assertEquals("android/support/multidex/MultiDex$V4.class", map.get("android/support/a/d.class"));
        } finally {
            reader.close();
        }
    }
}
